@@ -17,11 +17,10 @@ package Dist::Zilla::PluginBundle::Author::CJM;
 # ABSTRACT: Build a distribution like CJM
 #---------------------------------------------------------------------
 
-our $VERSION = '4.31';
-# This file is part of Dist-Zilla-PluginBundle-Author-CJM 4.31 (December 21, 2013)
+our $VERSION = '4.32';
+# This file is part of Dist-Zilla-PluginBundle-Author-CJM 4.32 (January 31, 2015)
 
 use Moose;
-use Moose::Autobox;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
 
@@ -48,10 +47,10 @@ sub configure
     ),
     [PodLoom => {
       data => 'tools/loom.pl',
-      $self->config_slice({
+      %{ $self->config_slice({
         pod_finder   => 'finder',
         pod_template => 'template',
-      })->flatten,
+      }) },
     } ],
     # either MakeMaker or ModuleBuild:
     [ ($arg->{builder} || 'MakeMaker') =>
@@ -122,8 +121,8 @@ Dist::Zilla::PluginBundle::Author::CJM - Build a distribution like CJM
 
 =head1 VERSION
 
-This document describes version 4.31 of
-Dist::Zilla::PluginBundle::Author::CJM, released December 21, 2013.
+This document describes version 4.32 of
+Dist::Zilla::PluginBundle::Author::CJM, released January 31, 2015.
 
 =head1 SYNOPSIS
 
@@ -280,7 +279,7 @@ L<< https://github.com/madsen/dist-zilla-pluginbundle-cjm >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Christopher J. Madsen.
+This software is copyright (c) 2015 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
